#
# spec file for package jfrog-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define executable_name jf

Name:           jfrog-cli
Version:        2.78.1
Release:        1.1
Summary:        A client that automates access to the JFrog products
License:        Apache-2.0
URL:            https://github.com/jfrog/jfrog-cli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  zsh
BuildRequires:  golang(API) >= 1.24
Provides:       %{executable_name} = %{version}

%description
JFrog CLI is a compact and smart client that provides a simple interface that
automates access to Artifactory and Mission Control through their respective
REST APIs. By using the JFrog CLI, you can greatly simplify your automation
scripts making them more readable and easier to maintain. Several features of
the JFrog CLI makes your scripts more efficient and reliable:

- Multithreaded upload and download of artifacts make builds run faster
- Checksum optimization reduces redundant file transfers
- Wildcards and regular expressions give you an easy way to collect all the
  artifacts you wish to upload or download.
- "Dry run" gives you a preview of file transfer operations before you actually
run them

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -trimpath \
   -o bin/%{executable_name}

%install
# Install the binary.
install -D -m 0755 bin/%{executable_name} %{buildroot}/%{_bindir}/%{executable_name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{executable_name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}
# delete the shebang
sed -i '1d' %{buildroot}%{_datarootdir}/bash-completion/completions/%{executable_name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{executable_name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish
# delete the shebang
sed -i '1d' %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{executable_name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}
# delete the shebang
sed -i '1d' %{buildroot}%{_datarootdir}/zsh/site-functions/_%{executable_name}

%check
%{buildroot}/%{_bindir}/%{executable_name} --version
%{buildroot}/%{_bindir}/%{executable_name} --version | grep %{version}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{executable_name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{executable_name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{executable_name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{executable_name}

%changelog
* Thu Jul 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.78.1:
  * Improvements
  - replace sast fingerprint to significant path by @hadarshjfrog
    in jfrog/jfrog-cli-security#498
  - Add partialFingerprints to result sarif by @solganik in
    jfrog/jfrog-cli-security#510
  * Bug Fixes
  - Fix build failure logic to consider applied policies rules by
    @eranturgeman in jfrog/jfrog-cli-security#501
  * Other Changes
  - IDE setup for vscode and jetbrains by @agrasth in #3027
  - Fixed the proper handling of deletionStatus by
    @naveenku-jfrog in jfrog/jfrog-client-go#1142
  - Add properties for repository via j frog cli by
    @naveenku-jfrog in jfrog/jfrog-client-go#1148
  - get all permisison targets(fix jfrog/jfrog-client-go#569) by
    @legnoh in jfrog/jfrog-client-go#1141
* Thu Jul 24 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.78.0:
  * Exciting New Features
  - Add versioning support to worker commands by @ehl-jf in #3018
  * Improvements
  - Add OIDC context struct by @EyalDelarea in #3014
  * Other Changes
  - Add Ruby gems support to JFrog CLI by @agrasth in #2992
  - Remove scanning of unused resources when creating binaries by
    @naveenku-jfrog in #3016
  - Remove audit command and add scan command by @naveenku-jfrog
    in #3019
  - Add properties for repository via the JFrog CLI by
    @naveenku-jfrog in #3025
  * Dependencies
  - Bump go version to 1.24 (#3037)
* Fri Jun 13 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.77.0:
  * Exciting New Features
  - Added curation audit for gradle by @basel1322 in
    jfrog/jfrog-cli-security#455
  - Support new command (source-mcp) by @ilya-k-1 in
    jfrog/jfrog-cli-security#448
  * Bug Fixes
  - Fix for mismatching cpu type for macos arm64 architecture by
    @bhanurp in #2993
  * Improvements
  - Update to --watches flag documentation by @eranturgeman in
    jfrog/jfrog-cli-security#461
* Thu May 29 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.76.1:
  * Improvements
  - Support for JFrog Advanced Security (JAS) in scan command by
    @guyshe-jfrog in jfrog-cli-security#407
  - Add support for non-standard package.json locations in npm
    tarballs by @agrasth in jfrog-cli-artifactory#78
  * Bug Fixes
  - Pass Project key to xray api if provided by @attiasas in
    jfrog-cli-security#454
  - Fixed a failure when trying to read if spec flag is set by
    @bhanurp in jfrog-cli-artifactory#77
* Mon May 19 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.76.0:
  * Exciting New Features
  - Introduced new lifecycle annotate command by @rimapol in
    [#2964]
  * Bug Fixes
  - Fix bug to use Maven wrapper when DepTreeParams.UseWrapper is
    true by @ranma2913 in jfrog/jfrog-cli-security#420
  - BuildScan - Fix parse violations if requested to show by
    @attiasas in jfrog/jfrog-cli-security#422
* Thu May  8 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 2.75.1:
  * Improvements
  - Update Analyzer Manager to v1.17.0 by @attiasas in
    jfrog/jfrog-cli-security#411
  * Bug Fixes
  - Fix jf eot command output by @EyalDelarea in #2961
  - Added no cache flag to gradle dep tree by @eyalk007 in
    jfrog/jfrog-cli-security#413
* Fri May  2 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package jfrog-cli: client that automates access to the JFrog
  products
